@@ -25,10 +25,10 @@ class SafeConnect:
         try:
             dbname = self.db_cls.__name__
             if dbname not in pool:
-                self.log_cls.info(f"初始化{dbname}数据池")
+                self.log_cls.debug(f"初始化{dbname}数据池")
                 pool[dbname] = PooledDB(creator=self.db_cls, maxconnections=4, **self.db_conf)
             self.conn = pool[dbname].connection()
-            self.log_cls.warning("数据库链接打开")
+            self.log_cls.debug("数据库链接打开")
             if self.format == DBFormat.TP:
                 cursor = self.conn.cursor()
             else:
@@ -44,7 +44,7 @@ class SafeConnect:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.conn.close()
-        self.log_cls.warning("数据库链接关闭")
+        self.log_cls.debug("数据库链接关闭")
 
 
 class DBBase:
@@ -85,7 +85,7 @@ class DBBase:
         else:
             return result
 
-    def Query(self, sql, format=DBFormat.DT, Param=None):
+    def Query(self, sql, Param=None, format=DBFormat.DT):
         with SafeConnect(self.__tp, format) as (conn, cursor):
             try:
                 self.__executeParam(cursor, sql, Param)
@@ -97,7 +97,7 @@ class DBBase:
             finally:
                 self.__log_cls.debug("query over")
 
-    def QuerySingle(self, sql, format=DBFormat.DT, Param=None):
+    def QuerySingle(self, sql, Param=None, format=DBFormat.DT):
         with SafeConnect(self.__tp, format) as (conn, cursor):
             try:
                 self.__executeParam(cursor, sql, Param)
